@@ -100,6 +100,9 @@ METRIC.G <- function(image.DN, WeatherStation=WeatherStation, Rn,
 #' @param aoi              SpatialPolygon object with limits of Area of interest
 #' @param alb.coeff        coefficient to transform narrow to broad band albedo.
 #' See Details.
+#' @param LST.method       Method for land surface temperature estimation. "SC" 
+#' for single channel or "SW" for split window algorithm. 
+#' "SW" is only available for L8. See \code{water::surfaceTemperature}
 #' @param LAI.method       Method used to estimate LAI from spectral data. 
 #' See Details.
 #' @param Zom.method       method selected to calculate momentum roughness 
@@ -108,6 +111,7 @@ METRIC.G <- function(image.DN, WeatherStation=WeatherStation, Rn,
 #' Perrier equation as in Santos et al (2012) and Pocas et al (2014).
 #' @param anchors.method   method to select anchor pixels. Currently only 
 #' "CITRA-MCB" automatic method available.
+#' @param n                number of pair of anchors pixels to calculate
 #' @param ETp.coef         ETp coefficient usually 1.05 or 1.2 for alfalfa
 #' @param Z.om.ws          momentum roughness lenght for WeatherStation. Usually
 #' 0.0018 or 0.03 for long grass
@@ -125,9 +129,10 @@ METRIC.G <- function(image.DN, WeatherStation=WeatherStation, Rn,
 #' @export
 METRIC.EB <- function(image.DN, WeatherStation, MTL, sat = "auto",
                       thermalband, plain=TRUE, DEM, aoi,
-                      alb.coeff = "Tasumi", LAI.method = "metric2010", 
+                      alb.coeff = "Tasumi", LST.method = "SC",
+                      LAI.method = "metric2010", 
                       Zom.method = "short.crops", anchors.method = "CITRA-MCB",
-                      ETp.coef= 1.05, Z.om.ws=0.0018, ESPA = FALSE, 
+                      n = 1, ETp.coef= 1.05, Z.om.ws=0.0018, ESPA = FALSE, 
                       verbose = FALSE){
   path=getwd()
   #pb <- txtProgressBar(min = 0, max = 100, style = 3)
@@ -158,24 +163,29 @@ METRIC.EB <- function(image.DN, WeatherStation, MTL, sat = "auto",
   Rl.inc <- incLWradiation(WeatherStation,DEM = surface.model$DEM, 
                            solar.angles = solar.angles.r, Ts= Ts)
   Rn <- netRadiation(LAI, albedo, Rs.inc, Rl.inc, Rl.out)
+  Rn[Rn < 0]  <-  0
   #setTxtProgressBar(pb, 40)
   G <- soilHeatFlux(image = image.SR, Ts=Ts,albedo=albedo, 
                     Rn=Rn, image.SR, LAI=LAI)
+  G[G < 0]  <-  0
   Z.om <- momentumRoughnessLength(LAI=LAI, mountainous = TRUE, 
                                   method = Zom.method, 
                                   surface.model = surface.model)
-  hot.and.cold <- calcAnchors(image = image.TOAr, Ts = Ts, LAI = LAI, plots = F,
-                              albedo = albedo, Z.om = Z.om, n = 1, 
-                              anchors.method = anchors.method,
+  par(mfrow=c(1,2))
+  hot.and.cold <- calcAnchors(image = image.TOAr, Ts = Ts, LAI = LAI, plots = T,
+                              albedo = albedo, Z.om = Z.om, n = n, 
+                              anchors.method = anchors.method, WeatherStation = WeatherStation,
                               deltaTemp = 5, verbose = verbose)
   print(hot.and.cold)
   #setTxtProgressBar(pb, 45)
-  H <- calcH(anchors = hot.and.cold, Ts = Ts, Z.om = Z.om, 
-             WeatherStation = WeatherStation, ETp.coef = ETp.coef, 
+  H <- calcH(anchors = hot.and.cold, Ts = Ts, Z.om = Z.om, mountainous = !plain,
+             WeatherStation = WeatherStation, ETp.coef = ETp.coef,
              Z.om.ws = Z.om.ws, DEM = DEM, Rn = Rn, G = G, verbose = verbose)
+  par(mfrow=c(1,1))
   #setTxtProgressBar(pb, 99)
   H <-  H$H
   LE <- Rn - G - H
+  LE[LE < 0]  <-  0
   EB <- stack(Rn, G, H, LE, Ts)
   EB <- saveLoadClean(imagestack = EB,
                 stack.names = c("NetRadiation", "SoilHeat", "SensibleHeat", 
