@@ -1,4 +1,3 @@
-
 #' Create aoi polygon from topleft and bottomright coordinates
 #' @description
 #' An AOI (Area of Interest) is created based on two points (topleft and bottomright) using a coordinate reference system.
@@ -26,182 +25,6 @@ createAoi <- function(topleft, bottomright, EPSG){
   return(aoi)
 }
 
-#' Load Landsat data from folder
-#' @description
-#' This function loads Landsat bands from a specific folder. 
-#' @param path  folder where band files are stored
-#' @param sat   "L7" for Landsat 7, "L8" for Landsat 8 or "auto" to guess from filenames
-#' @param aoi   area of interest to crop images, if waterOptions("autoAoi") == 
-#' TRUE will look for any object called aoi on .GlobalEnv
-#' @author Guillermo Federico Olmedo
-#' @author Fonseca-Luengo, David
-#' @references 
-#' R. G. Allen, M. Tasumi, and R. Trezza, "Satellite-based energy balance for mapping evapotranspiration with internalized calibration (METRIC) - Model" Journal of Irrigation and Drainage Engineering, vol. 133, p. 380, 2007 \cr
-#' @export
-loadImage <-  function(path = getwd(), sat="auto", aoi){
-  if(sat=="auto"){sat = getSat(path)} #DRY!
-  if(sat=="L8"){bands <- 2:7}
-  if(sat=="L7"){bands <- c(1:5,7)}
-  
-  stack1 <- list()
-  for(i in 1:6){
-    stack1[i] <- raster(list.files(path=path, 
-      pattern = paste0("^L[EC]\\d+\\w+\\d+_(B|band)", bands[i] ,".(TIF|tif)$")))
-  }
-  raw.image <- do.call(stack, stack1)
-  raw.image <- aoiCrop(raw.image, aoi)                               
-  raw.image <- saveLoadClean(imagestack = raw.image, 
-                       stack.names = c("B", "G", "R", "NIR", "SWIR1", "SWIR2"), 
-                       file = "imageDN", 
-                       overwrite=TRUE)
-  return(raw.image) 
-}  
-
-#' Calculates Top of atmosphere reflectance
-#' @description
-#' This function calculates the TOA (Top Of Atmosphere) reflectance considering only the image metadata.
-#' @param image.DN      raw image in digital numbers
-#' @param sat           "L7" for Landsat 7, "L8" for Landsat 8 or "auto" to guess from filenames 
-#' @param ESPA          Logical. If TRUE will look for espa.usgs.gov related products on working folder
-#' @param aoi           area of interest to crop images, if waterOptions("autoAoi") == TRUE will look for any object called aoi on .GlobalEnv
-#' @param incidence.rel solar incidence angle, considering the relief
-#' @param MTL           Landsat Metadata File
-#' @author Guillermo Federico Olmedo
-#' @author Fonseca-Luengo, David
-#' @references 
-#' R. G. Allen, M. Tasumi, and R. Trezza, "Satellite-based energy balance for mapping evapotranspiration with internalized calibration (METRIC) - Model" Journal of Irrigation and Drainage Engineering, vol. 133, p. 380, 2007 \cr
-#'
-#' LPSO. (2004). Landsat 7 science data users handbook, Landsat Project Science Office, NASA Goddard Space Flight Center, Greenbelt, Md., (http://landsathandbook.gsfc.nasa.gov/) (Feb. 5, 2007) \cr
-#' @export
-calcTOAr <- function(image.DN, sat="auto", 
-                     ESPA=FALSE, aoi, incidence.rel, MTL){
-  path = getwd()
-  if(sat=="auto"){sat = getSat(path)}
-  if(sat=="L8"){bands <- 2:7}
-  if(sat=="L7"){bands <- c(1:5,7)}
-  if(ESPA==TRUE & sat=="L8"){
-    files <- list.files(path = path, pattern = "_toa_band+[2-7].tif$", full.names = T)
-    stack1 <- list()
-    for(i in 1:6){
-      stack1[i] <- raster(files[i])
-    }
-    image_TOA <- do.call(stack, stack1)
-    image_TOA <- aoiCrop(image_TOA, aoi)
-    image_TOA <- image_TOA / 10000
-  }
-  ### Ro TOA L7
-  if(sat=="L7"){
-    if(missing(MTL)){MTL <- list.files(path = path, pattern = "MTL.txt", full.names = T)}
-    MTL <- readLines(MTL, warn=FALSE)
-    ESUN <- c(1997, 1812, 1533, 1039, 230.8, 84.90) # Landsat 7 Handbook
-    ## On sect 11.3, L7 handbook recommends using this formula for Ro TOA
-    ## O using DN - QCALMIN with METRIC 2010 formula.
-    Gain <- c(1.181, 1.210, 0.943, 0.969, 0.191, 0.066)
-    Bias <- c(-7.38071, -7.60984, -5.94252, -6.06929, -1.19122, -0.41650)
-    if(missing(image.DN)){image.DN <- loadImage(path = path)}
-    time.line <- grep("SCENE_CENTER_TIME",MTL,value=TRUE)
-    date.line <- grep("DATE_ACQUIRED",MTL,value=TRUE)
-    sat.time <-regmatches(time.line,regexec(text=time.line,
-                                            pattern="([0-9]{2})(:)([0-9]{2})(:)([0-9]{2})(.)([0-9]{2})"))[[1]][1]
-    sat.date <-regmatches(date.line,regexec(text=date.line,
-                                            pattern="([0-9]{4})(-)([0-9]{2})(-)([0-9]{2})"))[[1]][1]
-    sat.datetime <- strptime(paste(sat.date, sat.time), 
-                             format = "%Y-%m-%d %H:%M:%S", tz="GMT")
-    DOY <-  sat.datetime$yday +1
-    d2 <- 1/(1+0.033*cos(DOY * 2 * pi/365))
-    dr <- 1 + 0.033 * cos(DOY * (2 * pi / 365))
-    Ro.TOAr <- list()
-    for(i in 1:6){
-      Ro.TOAr[i] <- (pi * (Gain[i] * image.DN[[i]] + Bias[i])) / (ESUN[i] * cos(incidence.rel) * dr)
-    }
-    image_TOA <- do.call(stack, Ro.TOAr)
-  }
-  #### 
-  image_TOA <- saveLoadClean(imagestack = image_TOA, 
-                             stack.names = c("B", "G", "R", "NIR", "SWIR1", "SWIR2"), 
-                             file = "image_TOAr", 
-                             overwrite=TRUE)
-  return(image_TOA)
-}  
-
-#' Calculates surface reflectance for L7
-#' @description
-#' Calculates surface reflectance from top of atmosphere radiance using the model developed by Tasumi et al. (2008) and Allen et al. (2007), which considers a band-by-band basis.
-#' @param image.TOAr      raster stack. top of atmosphere reflectance image
-#' @param sat             "L7" for Landsat 7, "L8" for Landsat 8 or "auto" to guess from filenames 
-#' @param ESPA            Logical. If TRUE will look for espa.usgs.gov related products on working folder
-#' @param aoi             area of interest to crop images, if waterOptions("autoAoi") == TRUE will look for any object called aoi on .GlobalEnv
-#' @param incidence.hor   solar incidence angle, considering plain surface
-#' @param WeatherStation  Weather Station data
-#' @param surface.model   rasterStack with DEM, Slope and Aspect. See surface.model()
-#' @author Guillermo Federico Olmedo
-#' @author Fonseca-Luengo, David 
-#' @references 
-#' Tasumi M.; Allen R.G. and Trezza, R. At-surface albedo from Landsat and MODIS satellites for use in energy balance studies of evapotranspiration Journal of Hydrolog. Eng., 2008, 13, (51-63) \cr
-#'
-#' R. G. Allen, M. Tasumi, and R. Trezza, "Satellite-based energy balance for mapping evapotranspiration with internalized calibration (METRIC) - Model" Journal of Irrigation and Drainage Engineering, vol. 133, p. 380, 2007 \cr
-#' @export
-# incidence hor from TML?? 
-calcSR <- function(image.TOAr, sat="auto", ESPA=FALSE, aoi, incidence.hor, 
-                   WeatherStation, surface.model){
-  if(class(WeatherStation)== "waterWeatherStation"){
-    WeatherStation <- getDataWS(WeatherStation)
-  }
-  path <- getwd()
-  if(sat=="auto"){sat = getSat(path)}
-  if(sat=="L8"){bands <- 2:7}
-  if(sat=="L7"){bands <- c(1:5,7)}
-  if(ESPA==TRUE & sat=="L8"){
-    files <- list.files(path = path, pattern = "_sr_band+[2-7].tif$", full.names = T)
-    stack1 <- list()
-    for(i in 1:6){
-      stack1[i] <- raster(files[i])
-    }
-    image_SR <- do.call(stack, stack1)
-    image_SR <- aoiCrop(image_SR, aoi) 
-    image_SR <- image_SR / 10000
-  }
-  if(sat=="L7"){
-    if(missing(image.TOAr)){image.TOAr <- calcTOAr()}
-    P <- 101.3*((293-0.0065 * surface.model$DEM)/293)^5.26
-    ea <- (WeatherStation$RH/100)*0.6108*exp((17.27*WeatherStation$temp)/(WeatherStation$temp+237.3))
-    W <- 0.14 * ea * P + 2.1
-    Kt <- 1
-    Cnb <- matrix(data=c(0.987, 2.319, 0.951, 0.375, 0.234, 0.365,
-                         -0.00071, -0.00016, -0.00033, -0.00048, -0.00101, -0.00097,
-                         0.000036, 0.000105, 0.00028, 0.005018, 0.004336, 0.004296,
-                         0.0880, 0.0437, 0.0875, 0.1355, 0.056, 0.0155,
-                         0.0789, -1.2697, 0.1014, 0.6621, 0.7757, 0.639,
-                         0.64, 0.31, 0.286, 0.189, 0.274, -0.186), byrow = T, nrow=6, ncol=6)
-    tau_in <- list()
-    tau_out <- list()
-    for(i in 1:6){
-      tau_in[i] <- Cnb[1,i] * exp((Cnb[2,i]*P/(Kt*cos(incidence.hor)))-
-                                    ((Cnb[3,i]*W+Cnb[4,i])/cos(incidence.hor)))+Cnb[5,i]
-    }
-    eta = 0 # eta it's the satellite nadir angle
-    for(i in 1:6){
-      tau_out[i] <- Cnb[1,i] * exp((Cnb[2,i]*P/(Kt*cos(eta)))-
-                                     ((Cnb[3,i]*W+Cnb[4,i])/cos(eta)))+Cnb[5,i]
-    }
-    path_refl <- list()
-    for(i in 1:6){
-      path_refl[i] <- Cnb[6,i] * (1 - tau_in[[i]])
-    }
-    stack_SR <- list()
-    for(i in 1:6){
-      stack_SR[i] <- (image.TOAr[[i]] - path_refl[[i]]) / (tau_in[[i]] * tau_out[[i]])
-    }
-    image_SR <- do.call(stack, stack_SR)
-  }
-  image_SR <- saveLoadClean(imagestack = image_SR, 
-                            stack.names = c("B", "G", "R", "NIR", "SWIR1", "SWIR2"), 
-                            file = "image_SR", 
-                            overwrite=TRUE)
-  return(image_SR)
-}  
-
-
 #' Check needed SRTM grids from image extent
 #' @param raw.image  image to calculate extent
 #' @author Guillermo Federico Olmedo
@@ -445,7 +268,7 @@ albedo <- function(image.SR, aoi, coeff="Tasumi"){
 #' @details LAI is computed using the top-of atmosphere (at-satellite) reflectance value. 
 #' LAI and other indices such NDVI, SAVI are used to predict characteristics of vegetation, 
 #' depending on preferences of the user.
-#' Available methods are: "metric", "metric2010", "MCB" and "vineyard". 
+#' Available methods are: "metric", "metric2010", "MCB", "vineyard" and "turner". 
 #' @author Guillermo Federico Olmedo
 #' @author Fonseca-Luengo, David
 #' @author Fernando Fuentes Peñailillo
@@ -453,6 +276,7 @@ albedo <- function(image.SR, aoi, coeff="Tasumi"){
 #' R. G. Allen, M. Tasumi, and R. Trezza, "Satellite-based energy balance for mapping evapotranspiration with internalized calibration (METRIC) - Model" Journal of Irrigation and Drainage Engineering, vol. 133, p. 380, 2007 \cr
 #' Carrasco-Benavides, M., Ortega-Farias, S., Lagos, L., Kleissl, J., Morales-Salinas, L., & Kilic, A. (2014). Parameterization of the Satellite-Based Model (METRIC) for the Estimation of Instantaneous Surface Energy Balance Components over a Drip-Irrigated Vineyard. Remote Sensing, 6(11), 11342-11371. http://doi.org/10.3390/rs61111342\cr
 #' Johnson, L. F. (2003). Temporal Stability of the NDVI-LAI Relationship in a Napa Valley Vineyard, 96-101. http://doi.org/10.1111/j.1755-0238.2003.tb00258.x
+#' Turner, D. P., Cohen, W. B., Kennedy, R. E., Fassnacht, K. S., & Briggs, J. M. (1999). Relationships between leaf area index and Landsat TM spectral vegetation indices across three temperate zone sites. Remote Sensing of Environment, 70(1), 52–68. http://doi.org/10.1016/S0034-4257(99)00057-7
 #' @export
 ## Cite Pocas work for LAI from METRIC2010
 LAI <- function(method="metric2010", image, aoi, L=0.1){
@@ -531,42 +355,99 @@ SWtrasmisivity <- function(Kt = 1, ea, dem, incidence.hor){
 #' Estimates Land Surface Temperature from Landsat Data
 #' @description
 #' Surface temperature is estimated using a modified Plank equation considering empirical constants for Landsat images. In addition, this model implements a correction of thermal radiance following to Wukelic et al. (1989).
-#' @param thermalband     Satellite thermal band
+#' @param thermalband     Satellite thermal band. For L8 this should be band 10.
+#' @param thermalband2    Second thermal band. Only needed for split window method. For L8 this should be band 11.
 #' @param sat             "L7" for Landsat 7, "L8" for Landsat 8 or "auto" to guess from filenames 
 #' @param LAI             raster layer with leaf area index. See LAI()
-#' @param aoi             area of interest to crop images, if waterOptions("autoAoi") == TRUE will look for any object called aoi on .GlobalEnv
+#' @param aoi             area of interest to crop images, if 
+#'                        waterOptions("autoAoi") == TRUE will look for any 
+#'                        object called aoi on .GlobalEnv
+#' @param method          "SC" for single channel or "SW" for split window 
+#'                        algorithm. "SW" is only available for L8
 #' @param WeatherStation  Weather Station data
 #' @author Guillermo Federico Olmedo
 #' @author Fonseca-Luengo, David
 #' @references 
-#' R. G. Allen, M. Tasumi, and R. Trezza, "Satellite-based energy balance for mapping evapotranspiration with internalized calibration (METRIC) - Model" Journal of Irrigation and Drainage Engineering, vol. 133, p. 380, 2007 \cr
+#' R. G. Allen, M. Tasumi, and R. Trezza, "Satellite-based energy balance for 
+#' mapping evapotranspiration with internalized calibration (METRIC) - 
+#' Model" Journal of Irrigation and Drainage Engineering, vol. 133, 
+#' p. 380, 2007 \cr
 #'
-#' Wukelic G. E.; Gibbons D. E.; Martucci L. M. & Foote, H. P. Radiometric calibration of Landsat thematic mapper thermal band Remote Sensing of Environment, 1989, 28, (339-347) \cr
+#' Wukelic G. E.; Gibbons D. E.; Martucci L. M. & Foote, H. P. Radiometric 
+#' calibration of Landsat thematic mapper thermal band Remote Sensing of 
+#' Environment, 1989, 28, (339-347) \cr
+#'
+#' Jimenez-Munoz, J. C., Sobrino, J. A., Skokovic, D., Mattar, C., & Cristobal, 
+#' J. (2014). Land surface temperature retrieval methods from landsat-8 thermal 
+#' infrared sensor data.  IEEE Geoscience and Remote Sensing Letters, 11(10), 
+#' 1840–1843. http://doi.org/10.1109/LGRS.2014.2312032 \cr 
 #' @export
 ## Add Sobrino and Qin improvements to LST in ETM+
-## Add Rsky estimation from WeatherStation
-surfaceTemperature <- function(thermalband, sat="auto", LAI, aoi, 
-                               WeatherStation){
+surfaceTemperature <- function(thermalband, thermalband2, sat="auto", LAI, aoi, 
+                               method = "SC", WeatherStation){
   path=getwd()
   if(class(WeatherStation)== "waterWeatherStation"){
     WeatherStation <- getDataWS(WeatherStation)
   }
+  epsilon_NB <- raster(LAI)
+  epsilon_NB <- 0.97 + 0.0033 * LAI  
+  epsilon_NB[LAI > 3] <- 0.98
+  # Downwelling atm radiance
+  
+  R_sky <- (1.807e-10)*(WeatherStation$temp+273.15)^4*(1-0.26*
+                                            exp(-7.77e-4*WeatherStation$temp^2))
+  # path radiance
+  Rp <- 0.91     
+  # atm transmissivity
+  tau_NB <- 0.75+2e-5*WeatherStation$elev
   if(sat=="auto"){sat = getSat(path)}
   if(sat=="L8"){
     if(missing(thermalband)){
       bright.temp.b10 <- raster(list.files(path = path, 
-                                         pattern = "_toa_band10.tif"))
-      bright.temp.b10 <- aoiCrop(bright.temp.b10, aoi) 
-      Ts <- bright.temp.b10 * 0.1
+                                         pattern = "_toa_band10.tif$"))
     } else {
-      bright.temp.b10 <- aoiCrop(thermalband, aoi) 
-      Ts <- bright.temp.b10 * 0.1
+      bright.temp.b10 <- thermalband
+    }
+    bright.temp.b10 <- aoiCrop(bright.temp.b10, aoi) 
+    bright.temp.b10 <- bright.temp.b10 * 0.1
+    L_b10 <-  aoiCrop(raster(list.files(path = path, 
+                                pattern = "band10.tif$")[1]), aoi)
+    L_b10 <- L_b10* 3.3420E-04 + 0.1
+    if(method == "SC"){
+      #atm.coeff from Jimenez-Munoz, 2014
+      atm.coeff <- matrix(data=c(0.04019, 0.02916, 1.01523,
+                                 -0.38333, -1.50294, 0.20324,
+                                 0.00918, 1.36072, -0.27514),
+                          byrow= TRUE, nrow= 3, ncol=3)
+      ea = (WeatherStation$RH/100)*0.6108*exp((17.27*WeatherStation$temp)/
+                                                (WeatherStation$temp+237.3))
+      atm.cond <- matrix(data=c(ea^2, ea, 1), nrow= 3, ncol=1) #not ea, vwc in g/cm2
+      AF.j <- atm.coeff %*% atm.cond
+      AF.m <- c(1/tau_NB, -R_sky - (Rp/tau_NB), R_sky)
+      delta <- (bright.temp.b10^2)/(1324*L_b10 )
+      gama <- bright.temp.b10 - (bright.temp.b10^2/1324)
+      Ts <- delta*((1/epsilon_NB)*(AF.m[1]*L_b10+AF.m[2])+AF.m[3])+gama
+    }
+    if(method=="SW"){
+      if(missing(thermalband2)){
+        bright.temp.b11 <- raster(list.files(path = path, 
+                                             pattern = "_toa_band11.tif$"))
+      } else {
+        bright.temp.b11 <- thermalband2
+      }
+      bright.temp.b11 <- aoiCrop(bright.temp.b11, aoi) 
+      bright.temp.b11 <- bright.temp.b11 * 0.1 # L8 rescaling factor
+      SW.c <- c(-0.268, 1.378, 0.183, 54.30, -2.238, -129.20, 16.40)
+      w <- 1.2 #Atm water vapor content in g cm-2
+      delta_e <- 0 # emissivity difference 
+      Ts <- bright.temp.b10 + SW.c[2] * (bright.temp.b10 - bright.temp.b11) +
+        SW.c[3] * (bright.temp.b10 - bright.temp.b11)^2 + SW.c[1] +
+        (SW.c[4] + SW.c[5] * w) * (1 - epsilon_NB) 
+      # If I had two different emissivity, I should change epsilon_NB parameter
+      # with the mean emissivity and add +(SW.c[6] + SW.c[7] * w) * delta_e
     }
   }
   if(sat=="L7"){
-    epsilon_NB <- raster(LAI)
-    epsilon_NB <- 0.97 + 0.0033 * LAI  
-    epsilon_NB[LAI > 3] <- 0.98
     if(missing(thermalband)){
       B6 <- raster(list.files(path = path, 
                 pattern = "^L[EC]\\d+\\w+\\d+_B6_VCID_1.TIF$", full.names = T))
@@ -579,14 +460,6 @@ surfaceTemperature <- function(thermalband, sat="auto", LAI, aoi,
     }
     L7_K1 <- 666.09 
     L7_K2 <- 1282.71 
-    Rp <- 0.91             #Allen estimo en Idaho que el valor medio era 0.91
-    #tau_NB <- 1       #Allen estimo en Idaho que el valor medio era 0.866
-    ## There is a equation on excel to calculate from DEM
-    tau_NB <- 0.75+2e-5*WeatherStation$elev
-    #R_sky <- 1        #Allen estimo en Idaho que el valor medio era 1.32
-    ## There is a equation for R_sky on Metric Manual:
-    R_sky <- (1.807e-10)*(WeatherStation$temp+273.15)^4*(1-0.26*
-                                            exp(-7.77e-4*WeatherStation$temp^2))
     Rc <- ((L_t_6 - Rp) / tau_NB) - (1-epsilon_NB)*R_sky
     Ts <- L7_K2 / log((epsilon_NB*L7_K1/Rc)+1)}
   Ts <- saveLoadClean(imagestack = Ts, 
@@ -602,7 +475,9 @@ surfaceTemperature <- function(thermalband, sat="auto", LAI, aoi,
 #' @author Guillermo Federico Olmedo
 #' @author Fonseca-Luengo, David
 #' @references 
-#' R. G. Allen, M. Tasumi, and R. Trezza, "Satellite-based energy balance for mapping evapotranspiration with internalized calibration (METRIC) - Model" Journal of Irrigation and Drainage Engineering, vol. 133, p. 380, 2007 \cr
+#' R. G. Allen, M. Tasumi, and R. Trezza, "Satellite-based energy balance for 
+#' mapping evapotranspiration with internalized calibration (METRIC) - Model" 
+#' Journal of Irrigation and Drainage Engineering, vol. 133, p. 380, 2007 \cr
 #' @export
 outLWradiation <- function(LAI, Ts){
   surf.emissivity <- 0.95 + 0.01 * LAI
